[![Documentation Status](https://readthedocs.org/projects/neuron-morphology/badge/?version=latest)](https://neuron-morphology.readthedocs.io/en/latest/?badge=latest) [![Allen Institute](https://circleci.com/gh/AllenInstitute/neuron_morphology.svg?style=svg)](https://app.circleci.com/pipelines/github/AllenInstitute/neuron_morphology) [![Build status](https://ci.appveyor.com/api/projects/status/7fekclwnq58p61ax?svg=true)](https://ci.appveyor.com/project/fcollman/neuron-morphology)


neuron_morphology
=================

A package for working with single-neuron morphological reconstruction data, such as those in the [Allen Cell Types Database](https://celltypes.brain-map.org/). Provides tools for processing, visualizing, and analyzing such reconstructions.

For usage and installation instructions, see the [documentation](https://neuron-morphology.readthedocs.io/en/latest/).

Contributing
------------
We welcome contributions! Please see our [contribution guide](CONTRIBUTING.md) for more information. Thank you!

Level of Support
----------------
We are planning on occasional updating this tool with no fixed schedule. Community involvement is encouraged through both issues and pull requests.

